@@ -24,7 +24,7 @@
 #'
 #'   \code{neuron} objects containing connected trees can be converted to
 #'   \code{\link{ngraph}} objects, a lightweight wrapper around the
-#'   \code{\link{igraph}} library's \code{\link[igraph]{graph}} class that
+#'   \code{\link[igraph]{igraph}} library's \code{\link[igraph]{graph}} class that
 #'   preserves 3D coordinate information. This allows neurons to be manipulated
 #'   based on their graph structure, e.g. by finding all nodes upstream (closer
 #'   to the root) or downstream of a given node. The \code{\link{as.neuron}}
@@ -46,8 +46,8 @@
 #'   Metadata can be used to colour or subset the neurons during plotting (see
 #'   \code{\link{plot3d.neuronlist}} and \code{\link{subset.neuronlist}}).
 #'   Interactive 3D selection of neurons in a neuronlist is also possible using
-#'   \code{\link{find.neuron}} (which makes use of rgl's \code{\link{select3d}}
-#'   function.
+#'   \code{\link{find.neuron}} (which makes use of \code{rgl}'s
+#'   \code{\link[rgl]{select3d}} function.
 #'
 #'   \code{neuronlist} objects also provide additional functionality to
 #'   streamline arithmetic (e.g. scaling all the points in all neurons see
@@ -152,9 +152,8 @@
 #' @seealso \code{\link{neuron}}, \code{\link{dotprops}},
 #'   \code{\link{neuronlist}}, \code{\link{nlapply}}, \code{\link[nat]{plot3d}},
 #'   \code{\link{xform}}, \code{\link{im3d}}, \code{\link{read.hxsurf}},
-#'   \code{\link{rgl}} which is used for visualisation,
+#'   \code{\link[rgl]{rgl}} which is used for visualisation,
 #'   \code{\link{fileformats}}, \code{\link{read.neurons}}, \code{\link{cmtk}}.
-#' @docType package
 #' @keywords package
 #' @import rgl graphics grDevices utils
-NULL
+"_PACKAGE"
