@@ -1,10 +1,10 @@
 ## ----install, eval=FALSE------------------------------------------------------
 #  install.packages('nat', dependencies = TRUE)
 
-## ---- message=FALSE-----------------------------------------------------------
+## ----message=FALSE------------------------------------------------------------
 library(nat)
 
-## ---- include=FALSE-----------------------------------------------------------
+## ----include=FALSE------------------------------------------------------------
 # set up for knitr / 3D snapshot figures
 rgl::setupKnitr()
 library(knitr)
@@ -96,15 +96,15 @@ with(Cell07PNs, table(Glomerulus))
 ## -----------------------------------------------------------------------------
 Cell07PNs[, 'Glomerulus']
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  summary(Cell07PNs[,])
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  Cell07PNs[, 'NewColumn'] = somevariable
 #  Cell07PNs[, "Sex"] = sub("F", "female", Cell07PNs[, "Sex"])
 #  Cell07PNs[, "Sex"] = sub("M", "male", Cell07PNs[, "Sex"])
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  Cell07PNs[1:5, "Glomerulus"]
 #  Cell07PNs[Cell07PNs[, "Sex"]=="F", "Glomerulus"]
 #  
@@ -124,35 +124,35 @@ rotm=cmtkparams2affmat(rx=180)
 rotm=zapsmall(rotm)
 plot(xform(Cell07PNs, rotm))
 
-## ---- fig.width=8, fig.height=4-----------------------------------------------
+## ----fig.width=8, fig.height=4------------------------------------------------
 plot(Cell07PNs[[1]])
 
-## ---- fig.width=8, fig.height=4-----------------------------------------------
+## ----fig.width=8, fig.height=4------------------------------------------------
 plot(Cell07PNs[[1]], col='red', WithText=T)
 
-## ---- fig.width=8, fig.height=4-----------------------------------------------
+## ----fig.width=8, fig.height=4------------------------------------------------
 plot(Cell07PNs[1:3])
 
 ## -----------------------------------------------------------------------------
 plot(Cell07PNs, subset=Glomerulus!="DA1", col='grey', WithNodes=F, main="DA1 neurons")
 plot(Cell07PNs, subset=Glomerulus=="DA1", add=TRUE)
 
-## ---- webgl=TRUE, eval=use_rgl------------------------------------------------
-clear3d()
-plot3d(Cell07PNs[[1]], col='red')
-# set a grey background so it's easier to see extent of the webgl canvas
-bg3d(col='lightgrey')
+## ----webgl=TRUE, eval=use_rgl-------------------------------------------------
+#  clear3d()
+#  plot3d(Cell07PNs[[1]], col='red')
+#  # set a grey background so it's easier to see extent of the webgl canvas
+#  bg3d(col='lightgrey')
 
-## ---- rgl=TRUE, fig.width=6, eval=use_rgl-------------------------------------
-# 3d plot of neurons from olfactory glomeruli beginning with a D
-# coloured by glomerulus
-rval=plot3d(Cell07PNs, subset=grepl("^D", Glomerulus), col=Glomerulus,
-  lwd=2, WithNodes=FALSE)
+## ----rgl=TRUE, fig.width=6, eval=use_rgl--------------------------------------
+#  # 3d plot of neurons from olfactory glomeruli beginning with a D
+#  # coloured by glomerulus
+#  rval=plot3d(Cell07PNs, subset=grepl("^D", Glomerulus), col=Glomerulus,
+#    lwd=2, WithNodes=FALSE)
 
 ## ----plot3d-legend, fig.width=3, fig.height=3, eval=use_rgl-------------------
-# make a legend so that you know which colours match which glomerulus
-plot.new()
-with(attr(rval,'df'), legend('center', legend = unique(Glomerulus), fill=unique(col)))
+#  # make a legend so that you know which colours match which glomerulus
+#  plot.new()
+#  with(attr(rval,'df'), legend('center', legend = unique(Glomerulus), fill=unique(col)))
 
 ## -----------------------------------------------------------------------------
 # note that we had to use OmitFailures=T due to a problem with the graph
